@@ -111,6 +111,9 @@ spGP.Gibbs<-function(formula, data=parent.frame(), time.data, coords,
     if ( !is.matrix(coords) ) {
          stop("\n Error: coords must be a (n x 2) matrix of xy-coordinate locations \n")
     }
+    if ( (!is.numeric(coords[,1])) | (!is.numeric(coords[,2]))) {
+         stop("\n Error: coords columns should be numeric \n")
+    }
    #
      method <- distance.method
      spT.check.sites.inside(coords, method)
@@ -348,6 +351,9 @@ spGP.Gibbs<-function(formula, data=parent.frame(), time.data, coords,
         if (!is.matrix(pred.coords)) {
            stop("Error: prediction coords must be a (n x 2) matrix of xy-coordinate locations.")
         }
+        if ( (!is.numeric(pred.coords[,1])) | (!is.numeric(pred.coords[,2]))) {
+           stop("\n Error: prediction coords columns should be numeric \n")
+        }
       #
       #
       #  if (is.null(pred.X)){
@@ -411,7 +417,7 @@ spGP.Gibbs<-function(formula, data=parent.frame(), time.data, coords,
            coords.D <- as.matrix(spT.geodist(Lon=coords.all[,1],Lat=coords.all[,2], KM=FALSE))
       }
       else {
-       coords.D <- as.matrix(dist(coords.all, method, diag = T, upper = T))
+           coords.D <- as.matrix(dist(coords.all, method, diag = T, upper = T))
       }  
       #
            d12 <- coords.D[nfit.sites, npred.sites]
@@ -591,6 +597,9 @@ spGP.Gibbs<-function(formula, data=parent.frame(), time.data, coords,
        if ( !is.matrix(fore.coords) ) {
          stop("Error: fore.coords must be a matrix of xy-coordinate locations")
        }
+       if ( (!is.numeric(fore.coords[,1])) | (!is.numeric(fore.coords[,2]))) {
+         stop("\n Error: fore.coords columns should be numeric \n")
+       }
       #
            nsite <- dim(fore.coords)[[1]]
 
@@ -779,6 +788,9 @@ spGP.MCMC.Pred<-function(formula, data=parent.frame(), time.data,
     if ( !is.matrix(coords) ) {
          stop("\n Error: coords must be a (n x 2) matrix of xy-coordinate locations \n")
     }
+    if ( (!is.numeric(coords[,1])) | (!is.numeric(coords[,2]))) {
+         stop("\n Error: coords columns should be numeric \n")
+    }
     #
       method <- distance.method
       spT.check.sites.inside(coords, method)
@@ -905,6 +917,9 @@ spGP.MCMC.Pred<-function(formula, data=parent.frame(), time.data,
         if (!is.matrix(pred.coords)) {
            stop("Error: prediction coords must be a (n x 2) matrix of xy-coordinate locations.")
         }
+        if ( (!is.numeric(pred.coords[,1])) | (!is.numeric(pred.coords[,2]))) {
+           stop("\n Error: prediction coords columns should be numeric \n")
+        }
       #
       #
            coords.all <- rbind(coords,pred.coords)
